.. _spkg_json5:

json5: Python implementation of the JSON5 data format
=====================================================

Description
-----------

Python implementation of the JSON5 data format

License
-------

Apache

Upstream Contact
----------------

https://pypi.org/project/json5/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    0.12.0

version_requirements.txt::

    json5

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install json5

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i json5

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-json5


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
